==> deverhood-react-1.16.51.tgz: package/src/sagas/his.js <==
import {
  COMPONENT,
  GET,
  POST,
  PUT,
  DEL,
  ALL,
  HIS_API,
  HIS_REQUEST,
  SELF,
  REDIRECT_TO,
  CLEAR,
  INVENTORY,
  SEARCH,
  UNIT,
  LOTS,
  MEDIC_REQUEST,
  FOLLOWUP,
  OWN_MEDICATION,
  MEDICATION,
  INVOICE
} from "../actions/actionType.js";
import { put, fork, call, take, takeEvery } from "redux-saga/effects";
import graphql from "../services/graphql";
import query from "query";
const url = "his";
function* callback(isSuccess, error) {
  isSuccess
    ? yield put({
        type: COMPONENT.CALLBACK_SUCCESS
      })
    : yield put({
        type: COMPONENT.CALLBACK_FAIL,
        data: error.response.data.message
      });
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* loading() {
  yield put({
    type: COMPONENT.CALLBACK_LOADING
  });
}
function* complete() {
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* outOfRange() {
  yield put({
    type: COMPONENT.CALLBACK_OUT
  });
}
function* renew() {
  yield put({
    type: COMPONENT.CALLBACK_NEW
  });
}
function* request(actions) {
  switch (actions.api) {
    case GET:
      return yield fork(get, actions);
    case POST:
      return yield fork(post, actions);
    case PUT:
      return yield fork(change, actions);
    case DEL:
      return yield fork(del, actions);
    case ALL:
      return yield fork(getAll, actions);
    case SEARCH:
      return yield fork(search, actions);
    case CLEAR:
      return yield fork(clear, actions);
    default:
      null;
  }
}
function* clear(actions) {
  switch (actions.doc) {
    case INVENTORY:
      return yield put({
        type: HIS_API.INVENTORY.CLEAR.SUCCESS
      });
    default:
      break;
  }
}
function* getAll(actions) {
  try {
    switch (actions.doc) {
      case INVENTORY:
        yield call(loading);
        const service = "inventories";
        try {
          var response = yield call(
            graphql.graph,
            `{
  inventories(size:${actions.obj ? actions.obj.size : 100},page:${
              actions.obj ? actions.obj.page : 0
            }${actions.item ? `,args:"${actions.item}"` : ""}){
    ${actions.query.map(v => v + " ")}
  }
}
`,
            {},
            url,
            actions
          );
        } catch (e) {
          console.log(e);
        }
        yield put({
          type: HIS_API.INVENTORY.ALL.SUCCESS,
          data: response.data.data[service]
        });
        if (response.data.data[service].length == 0) {
          return yield call(outOfRange);
        } else {
          return yield call(complete);
        }
      case UNIT:
        yield call(loading);
        var response = yield call(
          graphql.get,
          "distributionUnits",
          url,
          actions
        );
        yield put({
          type: HIS_API.UNIT.ALL.SUCCESS,
          data: response.data.data.distributionUnits
        });
        return yield call(complete);
      case MEDICATION:
        yield call(loading);
        var response = yield call(
          graphql.get,
          "medications(size:1000)",
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.ALL.SUCCESS,
          data: response.data.data.medications
        });
        return yield call(complete);
      case OWN_MEDICATION:
        yield call(loading);
        console.log(actions);
        var response = yield call(
          graphql.get,
          `medications(size:1000,args:doc.visit.id=${actions.visitId})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.ALL.SUCCESS,
          data: response.data.data.medications
        });
        return yield call(complete);
      case INVOICE:
        yield call(loading);
        try {
          var response = yield call(
            graphql.get,
            `invoices(size:10,page:${actions.obj ? actions.obj.page : 0})`,
            url,
            actions
          );
          yield put({
            type: HIS_API.INVOICE.ALL.SUCCESS,
            data: response.data.data.invoices
          });
          if (response.data.data.invoices.length == 0) {
            return yield call(outOfRange);
          } else {
            return yield call(complete);
          }
        } catch (e) {
          console.log(e);
        }
      case SELF:
        yield call(loading);
        try {
          var response = yield call(
            graphql.get,
            `visits(size:10,page:${actions.obj ? actions.obj.page : 0})`,
            url,
            actions
          );
          yield put({
            type: HIS_API.SELF.ALL.SUCCESS,
            data: response.data.data.visits
          });
          if (response.data.data.visits.length == 0) {
            return yield call(outOfRange);
          } else {
            return yield call(complete);
          }
        } catch (e) {
          console.log(e);
        }
      default:
        null;
    }
  } catch (e) {
    return yield call(complete);
    console.log(e);
    //yield call(callback, false, e);
  }
}
function* get(actions) {
  try {
    switch (actions.doc) {
      case INVENTORY:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `inventory(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.INVENTORY.GET.SUCCESS,
          data: response.data.data.inventory
        });
        return yield call(complete);
      case SELF:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `visit(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.SELF.GET.SUCCESS,
          data: response.data.data.visit
        });
        return yield call(complete);
      case INVOICE:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `invoice(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.INVOICE.GET.SUCCESS,
          data: response.data.data.invoice
        });
        return yield call(complete);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* post(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case SELF:
        yield call(loading);
        var response = yield call(graphql.post, "Visit", url, {
          ...actions,
          item: {
            groupId: actions.item.groupId,
            patientId: actions.item.patientId
          }
        });
        yield put({
          type: HIS_API.SELF.POST.SUCCESS,
          data: response.data.data.insertVisit
        });
        if (actions.item.followUpDate) {
          yield put({
            type: MEDIC_REQUEST,
            api: POST,
            doc: FOLLOWUP,
            item: {
              followUpDate: actions.item.followUpDate,
              patientId: actions.item.patientId,
              visitId: response.data.data.insertVisit.id
            },
            query: query.medic.followUps
          });
        }
        return yield call(complete);
      case INVENTORY:
        yield call(loading);
        var response = yield call(graphql.post, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.POST.SUCCESS,
          data: response.data.data.insertInventory
        });
        yield call(callback, true);
        return history.back();
      case MEDICATION:
        yield call(loading);
        var response = yield call(graphql.post, "Medication", url, actions);
        yield put({
          type: HIS_API.MEDICATION.POST.SUCCESS,
          data: response.data.data.insertMedication
        });
        return yield call(callback, true);
      case LOTS:
        yield call(loading);
        var response = yield call(graphql.post, "InvPurchase", url, actions);
        yield put({
          type: HIS_API.LOTS.POST.SUCCESS,
          data: response.data.data.insertInvPurchase
        });
        return yield call(callback, true);
      case INVOICE:
        yield call(loading);
        var response = yield call(graphql.post, "Invoice", url, actions);
        yield put({
          type: HIS_API.INVOICE.POST.SUCCESS,
          data: response.data.data.insertInvoice
        });
        yield call(callback, true);
        return history.back();
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* change(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case INVENTORY:
        var response = yield call(graphql.sqlPut, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.PUT.SUCCESS,
          data: response.data.data.updateInventory
        });
        return yield call(callback, true);
      case LOTS:
        var response = yield call(graphql.sqlPut, "InvPurchase", url, actions);
        yield put({
          type: HIS_API.LOTS.PUT.SUCCESS,
          data: response.data.data.updateInvPurchase
        });
        return yield call(callback, true);
      case MEDICATION:
        var response = yield call(graphql.sqlPut, "Medication", url, actions);
        yield put({
          type: HIS_API.MEDICATION.PUT.SUCCESS,
          data: response.data.data.updateMedication
        });
        return yield call(complete);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* del(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case INVENTORY:
        var response = yield call(graphql.sqlDelete, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      case MEDICATION:
        var response = yield call(
          graphql.sqlDelete,
          "Medication",
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      case LOTS:
        var response = yield call(
          graphql.sqlDelete,
          "InvPurchase",
          url,
          actions
        );
        yield put({
          type: HIS_API.LOTS.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* search(actions) {
  try {
    switch (actions.doc) {
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
export function* watchHis() {
  yield takeEvery(HIS_REQUEST, request);
}

==> deverhood-react-1.16.59.tgz: package/src/sagas/his.js <==
import {
  COMPONENT,
  GET,
  POST,
  PUT,
  DEL,
  ALL,
  HIS_API,
  HIS_REQUEST,
  SELF,
  REDIRECT_TO,
  CLEAR,
  INVENTORY,
  SEARCH,
  UNIT,
  LOTS,
  MEDIC_REQUEST,
  FOLLOWUP,
  OWN_MEDICATION,
  MEDICATION,
  INVOICE
} from "../actions/actionType.js";
import { put, fork, call, take, takeEvery } from "redux-saga/effects";
import graphql from "../services/graphql";
import query from "query";
const url = "his";
function* callback(isSuccess, error) {
  isSuccess
    ? yield put({
        type: COMPONENT.CALLBACK_SUCCESS
      })
    : yield put({
        type: COMPONENT.CALLBACK_FAIL,
        data: error.response.data.message
      });
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* loading() {
  yield put({
    type: COMPONENT.CALLBACK_LOADING
  });
}
function* complete() {
  yield put({
    type: COMPONENT.SUCCESS
  });
}
function* outOfRange() {
  yield put({
    type: COMPONENT.CALLBACK_OUT
  });
}
function* renew() {
  yield put({
    type: COMPONENT.CALLBACK_NEW
  });
}
function* request(actions) {
  switch (actions.api) {
    case GET:
      return yield fork(get, actions);
    case POST:
      return yield fork(post, actions);
    case PUT:
      return yield fork(change, actions);
    case DEL:
      return yield fork(del, actions);
    case ALL:
      return yield fork(getAll, actions);
    case SEARCH:
      return yield fork(search, actions);
    case CLEAR:
      return yield fork(clear, actions);
    default:
      null;
  }
}
function* clear(actions) {
  switch (actions.doc) {
    case INVENTORY:
      return yield put({
        type: HIS_API.INVENTORY.CLEAR.SUCCESS
      });
    default:
      break;
  }
}
function* getAll(actions) {
  try {
    switch (actions.doc) {
      case INVENTORY:
        yield call(loading);
        const service = "inventories";
        try {
          var response = yield call(
            graphql.graph,
            `{
            inventories(size:${actions.obj ? actions.obj.size : 100},page:${
              actions.obj ? actions.obj.page : 0
            }${actions.item ? `,args:"${actions.item}"` : ""}){
              ${actions.query.map(v => v + " ")}
            }
          }
`,
            {},
            url,
            actions
          );
        } catch (e) {
          console.log(e);
        }
        yield put({
          type: HIS_API.INVENTORY.ALL.SUCCESS,
          data: response.data.data[service]
        });
        if (response.data.data[service].length == 0) {
          console.log("outOfRange");
          return yield call(outOfRange);
        } else {
          console.log("complete");
          return yield call(complete);
        }
      case UNIT:
        yield call(loading);
        var response = yield call(
          graphql.get,
          "distributionUnits",
          url,
          actions
        );
        yield put({
          type: HIS_API.UNIT.ALL.SUCCESS,
          data: response.data.data.distributionUnits
        });
        return yield call(complete);
      case MEDICATION:
        yield call(loading);
        var response = yield call(
          graphql.get,
          "medications(size:1000)",
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.ALL.SUCCESS,
          data: response.data.data.medications
        });
        return yield call(complete);
      case OWN_MEDICATION:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `medications(size:1000,args:"doc.visit.id=${actions.item.visitId}")`,
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.ALL.SUCCESS,
          data: response.data.data.medications
        });
        return yield call(complete);
      case INVOICE:
        yield call(loading);
        try {
          var response = yield call(
            graphql.get,
            `invoices(size:10,page:${actions.obj ? actions.obj.page : 0})`,
            url,
            actions
          );
          yield put({
            type: HIS_API.INVOICE.ALL.SUCCESS,
            data: response.data.data.invoices
          });
          if (response.data.data.invoices.length == 0) {
            return yield call(outOfRange);
          } else {
            return yield call(complete);
          }
        } catch (e) {
          console.log(e);
        }
      case SELF:
        yield call(loading);
        try {
          var response = yield call(
            graphql.get,
            `visits(size:10,page:${actions.obj ? actions.obj.page : 0})`,
            url,
            actions
          );
          yield put({
            type: HIS_API.SELF.ALL.SUCCESS,
            data: response.data.data.visits
          });
          if (response.data.data.visits.length == 0) {
            return yield call(outOfRange);
          } else {
            return yield call(complete);
          }
        } catch (e) {
          console.log(e);
        }
      default:
        null;
    }
  } catch (e) {
    return yield call(complete);
    console.log(e);
    //yield call(callback, false, e);
  }
}
function* get(actions) {
  try {
    switch (actions.doc) {
      case INVENTORY:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `inventory(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.INVENTORY.GET.SUCCESS,
          data: response.data.data.inventory
        });
        return yield call(complete);
      case SELF:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `visit(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.SELF.GET.SUCCESS,
          data: response.data.data.visit
        });
        return yield call(complete);
      case INVOICE:
        yield call(loading);
        var response = yield call(
          graphql.get,
          `invoice(id:${actions.id})`,
          url,
          actions
        );
        yield put({
          type: HIS_API.INVOICE.GET.SUCCESS,
          data: response.data.data.invoice
        });
        return yield call(complete);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* post(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case SELF:
        yield call(loading);
        var response = yield call(graphql.post, "Visit", url, {
          ...actions,
          item: {
            groupId: actions.item.groupId,
            patientId: actions.item.patientId
          }
        });
        yield put({
          type: HIS_API.SELF.POST.SUCCESS,
          data: response.data.data.insertVisit
        });
        if (actions.item.followUpDate) {
          yield put({
            type: MEDIC_REQUEST,
            api: POST,
            doc: FOLLOWUP,
            item: {
              followUpDate: actions.item.followUpDate,
              patientId: actions.item.patientId,
              visitId: response.data.data.insertVisit.id
            },
            query: query.medic.followUps
          });
        }
        return yield call(complete);
      case INVENTORY:
        yield call(loading);
        var response = yield call(graphql.post, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.POST.SUCCESS,
          data: response.data.data.insertInventory
        });
        yield call(callback, true);
        return history.back();
      case MEDICATION:
        yield call(loading);
        var response = yield call(graphql.post, "Medication", url, actions);
        yield put({
          type: HIS_API.MEDICATION.POST.SUCCESS,
          data: response.data.data.insertMedication
        });
        return yield call(callback, true);
      case LOTS:
        yield call(loading);
        var response = yield call(graphql.post, "InvPurchase", url, actions);
        yield put({
          type: HIS_API.LOTS.POST.SUCCESS,
          data: response.data.data.insertInvPurchase
        });
        return yield call(callback, true);
      case INVOICE:
        yield call(loading);
        var response = yield call(graphql.post, "Invoice", url, actions);
        yield put({
          type: HIS_API.INVOICE.POST.SUCCESS,
          data: response.data.data.insertInvoice
        });
        yield call(callback, true);
        return history.back();
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* change(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case INVENTORY:
        var response = yield call(graphql.sqlPut, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.PUT.SUCCESS,
          data: response.data.data.updateInventory
        });
        return yield call(callback, true);
      case LOTS:
        var response = yield call(graphql.sqlPut, "InvPurchase", url, actions);
        yield put({
          type: HIS_API.LOTS.PUT.SUCCESS,
          data: response.data.data.updateInvPurchase
        });
        return yield call(callback, true);
      case MEDICATION:
        var response = yield call(graphql.sqlPut, "Medication", url, actions);
        yield put({
          type: HIS_API.MEDICATION.PUT.SUCCESS,
          data: response.data.data.updateMedication
        });
        return yield call(complete);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* del(actions) {
  yield call(loading);
  try {
    switch (actions.doc) {
      case INVENTORY:
        var response = yield call(graphql.sqlDelete, "Inventory", url, actions);
        yield put({
          type: HIS_API.INVENTORY.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      case MEDICATION:
        var response = yield call(
          graphql.sqlDelete,
          "Medication",
          url,
          actions
        );
        yield put({
          type: HIS_API.MEDICATION.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      case LOTS:
        var response = yield call(
          graphql.sqlDelete,
          "InvPurchase",
          url,
          actions
        );
        yield put({
          type: HIS_API.LOTS.DEL.SUCCESS,
          data: actions.id
        });
        return yield call(callback, true);
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
function* search(actions) {
  try {
    switch (actions.doc) {
      default:
        null;
    }
  } catch (e) {
    console.log(e);
    yield call(callback, false, e);
  }
}
export function* watchHis() {
  yield takeEvery(HIS_REQUEST, request);
}
